Capital Bikeshare
Author: Alta Bicycle Share
Description: Your bike sharing system in Washington, D.C.
Keywords: Bicycle Sharing Systems

## Capital Bikeshare's NEW DAILY KEY option.

Learn More

## Proudly display your love of Capital Bikeshare.

Shop Now

## Find new station locations and plan your trip.

Learn More

## Choose from over 300 stations across D.C., Arlington, Alexandria, and Montgomery County.

Learn More

## Connect with transit trips for the first and last miles.

Learn More

## The first 30 minutes of each trip are free.

Learn More

## Capital Bikeshare puts over thousands of bicycles at your fingertips.

Learn More

# What Is Capital Bikeshare?

Capital Bikeshare puts over 2500 bicycles at your fingertips. You can choose any of the over 300 stations across Washington, D.C., Arlington and Alexandria, VA and Montgomery County, MD and return it to any station near your destination. Check out a bike for your trip to work, Metro, run errands, go shopping, or visit friends and family. Join Capital Bikeshare for a day, 3 days, a month, a year or try our new daily key option, and have access to our fleet of bikes 24 hours a day, 365 days a year. The first 30 minutes of each trip are free. Each additional 30 minutes incurs an additional fee.

Ver video en español